=== modified file 'cluster-controller-integration.py'
--- cluster-controller-integration.py	2013-04-25 16:30:48 +0000
+++ cluster-controller-integration.py	2013-10-10 13:01:22 +0000
@@ -36,7 +36,9 @@
         update_pxe_config()
 
     def test_import_pxe_files(self):
-        output, err = run_command(["maas-import-pxe-files"])
+        env = os.environ.copy()
+        env['http_proxy'] = HTTP_PROXY
+        output, err = run_command(["maas-import-pxe-files"], env=env)
         self.assertThat(output, Contains('Downloading to temporary location'))
         # XXX: matsubara Bug=1076444
         # maas-import-pxe-files outputs to stderr during normal operation.

=== modified file 'maas-integration.py'
--- maas-integration.py	2013-10-10 11:08:59 +0000
+++ maas-integration.py	2013-10-10 13:01:22 +0000
@@ -15,7 +15,7 @@
 import zmq
 
 from utils import (
-    run_command, timeout, CLUSTER_CONTROLLER_IP,
+    run_command, timeout, update_pxe_config, CLUSTER_CONTROLLER_IP,
     SQUID_DEB_PROXY_URL, assertStartedUpstartService, is_juju_core,
     is_precise, is_saucy)
 
@@ -295,28 +295,7 @@
             self, 'maas-pserv', '/var/log/maas/pserv.log')
 
     def test_update_pxe_config(self):
-        try:
-            ephemerals_fd = open("/etc/maas/import_ephemerals", "r+")
-        except IOError:
-            # In recent versions of maas, /etc/maas/import_ephemerals is
-            # gone.
-            pass
-        else:
-            ephemerals = ephemerals_fd.read()
-            # Update mirrors for both trunk and the quantal SRU.
-            ephemerals_snippet = (
-                '\n'
-                'CLOUD_IMAGES_ARCHIVE="http://10.98.0.13/mirrors/maas-ephemeral"\n'
-                'REMOTE_IMAGES_MIRROR="http://10.98.0.13/mirrors/maas-ephemeral"\n'
-            #    XXX: rvb 2013-01-18: Do not use the daily ephemeral images as
-            #    they seem to be broken (more precisely, the image from 20130107 is
-            #    and the one from 20121008 isn't);  investigation is underway.
-            #   'STREAM=daily\n'
-                )
-            ephemerals += ephemerals_snippet
-            ephemerals_fd.seek(0)
-            ephemerals_fd.write(ephemerals)
-            ephemerals_fd.close()
+        update_pxe_config()
 
     def test_import_pxe_files(self):
         env = os.environ.copy()

=== modified file 'utils.py'
--- utils.py	2013-10-10 10:26:44 +0000
+++ utils.py	2013-10-10 13:01:22 +0000
@@ -10,7 +10,6 @@
 
 
 CLUSTER_CONTROLLER_IP = '192.168.20.5'
-SQUID_PROXY_URL = 'http://10.98.0.13:3128'
 SQUID_DEB_PROXY_URL = 'http://10.98.0.13:8000'
 
 
@@ -68,6 +67,30 @@
     return stdout, stderr
 
 
+def update_pxe_config():
+    try:
+        ephemerals_fd = open("/etc/maas/import_ephemerals", "r+")
+    except IOError:
+        # In recent versions of maas, /etc/maas/import_ephemerals is
+        # gone.
+        pass
+    else:
+        ephemerals = ephemerals_fd.read()
+        # Update mirrors for both trunk and the quantal SRU.
+        ephemerals_snippet = (
+            '\n'
+            'CLOUD_IMAGES_ARCHIVE="http://10.98.0.13/mirrors/maas-ephemeral"\n'
+            'REMOTE_IMAGES_MIRROR="http://10.98.0.13/mirrors/maas-ephemeral"\n'
+        #    XXX: rvb 2013-01-18: Do not use the daily ephemeral images as
+        #    they seem to be broken (more precisely, the image from 20130107 is
+        #    and the one from 20121008 isn't);  investigation is underway.
+        #   'STREAM=daily\n'
+            )
+        ephemerals += ephemerals_snippet
+        ephemerals_fd.seek(0)
+        ephemerals_fd.write(ephemerals)
+        ephemerals_fd.close()
+
 def retries(timeout=30, delay=1):
     """Helper for retrying something, sleeping between attempts.
 

